<?php
/**
 * chiro functions and definitions
 *
 * @package chiro
 * @since 1.0.0
 */

// Useful global constants
define( 'CHIROTHEME_VERSION', '0.5.2' );

/**
 * Set up theme defaults and register supported WordPress features.
 * @since 0.1.0
 */
function chirotheme_setup() {
	register_nav_menu( 'primary', 'Primary Menu' );
	if ( ! isset( $content_width ) ) $content_width = 960;
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 1200, 675, true );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'custom-header', array(
		'random-default'         => false,
		'width'                  => 300,
		'height'                 => 80,
		'flex-height'            => true,
		'flex-width'             => true,
		'default-text-color'     => '',
		'header-text'            => false,
		'uploads'                => true,
		'wp-head-callback'       => '',
		'admin-head-callback'    => '',
		'admin-preview-callback' => '',
	));

	add_theme_support( 'custom-background' );
	add_editor_style("/assets/css/editor-style.css");
	load_theme_textdomain( 'chirotheme', get_template_directory() . '/languages' );
}

add_action( 'after_setup_theme', 'chirotheme_setup' );

function chirotheme_enqueue_scripts(){
	wp_enqueue_style( 'chirotheme_base',    get_template_directory_uri() . "/assets/css/chiro-base.css", array(), CHIROTHEME_VERSION );
	wp_enqueue_style( 'chirotheme_styling', get_template_directory_uri() . "/assets/css/chiro-styling.css", array(), CHIROTHEME_VERSION );
	wp_enqueue_style( 'chirotheme_font_open_sans', get_template_directory_uri() . "/assets/css/font-open-sans.css", array(), CHIROTHEME_VERSION );
	wp_enqueue_style( 'chirotheme_font_awesome',   get_template_directory_uri() . "/assets/css/font-awesome.css", array(), CHIROTHEME_VERSION );
}
add_action( 'wp_enqueue_scripts', 'chirotheme_enqueue_scripts' );

// Remove jQuery Migrate Script from header and Load jQuery from Google API
function chirotheme_deregister_scripts(){
	if (!is_user_logged_in()) {
		wp_deregister_script('wp-embed');
		// wp_deregister_script('jquery'); // jQuery wird von eventorganiser frontend.js benötigt
	}
}
add_action( 'wp_footer', 'chirotheme_deregister_scripts' );

add_action('init', function(){
	remove_action( 'admin_print_scripts', 'print_emoji_detection_script' );
	remove_action( 'admin_print_styles', 'print_emoji_styles' );
	remove_action( 'wp_head', 'print_emoji_detection_script', 7 );
	remove_action( 'wp_print_styles', 'print_emoji_styles' );
	remove_filter( 'the_content_feed', 'wp_staticize_emoji' );
});

//Returns a "Read more &raquo;" link for excerpts
function chirotheme_continue_reading_link() {
	return '<span class="read-more"><a href="'. esc_url(get_permalink()) . '">' . __( 'Read more &raquo;', 'chirotheme' ) . '</a></span>';
}

function wpdocs_custom_excerpt_length( $length ) { return 20; }
add_filter( 'excerpt_length', 'wpdocs_custom_excerpt_length', 999 );

//Append site title to wp_title.
function chirotheme_wp_title( $title, $sep, $seplocation ){ return $title . get_bloginfo('name'); }
add_filter( 'wp_title', 'chirotheme_wp_title', 10, 3 );

//Widgets
require_once( get_template_directory() . '/includes/widgetised-areas.php' );

/*
function chirotheme_get_author_id( $post_id = false ){
	$post_id = ( $post_id === false ? get_the_ID() : $post_id );
	$post_obj = get_post( $post_id );
	global $authordata;
	if ( !is_object( $authordata ) )
		return false;
	return (int) $authordata->ID;
}
*/
?>
